<?php

namespace App\Http\Controllers;

use App\Country;
use App\DegreeType;
use App\EnglishTest;
use App\ProgramCategory;
use App\Student;
use App\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Session;

class HomeController extends Controller
{
    public function index(){
        $countries = Country::get();
        $subjects = ProgramCategory::get();
        $degrees = DegreeType::get();
        $eng_test = EnglishTest::get();
        return view('welcome',compact('countries','subjects','degrees','eng_test'));
    }

    public function findPrograms(Request $request)
    {
        if ( $request->eng_test == 1 ) {
            $max = 10;
        }
        else {
            $max = 100;
        }
        $request->validate([
            'full_name' => 'required|max:50',
            'email' => 'required|unique:users',
            'nationality' => 'required',
            'contact_no' => 'required|unique:users',
            'subject' => 'required',
            'destination_country' => 'required',
            'last_degree' => 'required',
            'eng_test' => 'required',
            'writing' => 'required|numeric|min:1|max:'.$max,
            'reading' => 'required|numeric|min:1|max:'.$max,
            'speaking' => 'required|numeric|min:1|max:'.$max,
            'listening' => 'required|numeric|min:1|max:'.$max,
        ]);
        Session::put('find_programs',$request->all());
        return redirect()->route('institute_listing');
    }

    public function searchStudent(Request $request)
    {
        if($request->has('agent_id')){
            $students = Student::where('reference',$request->agent_id)->where('name','LIKE','%'.$request->input('query').'%')->get();
        }else{
            if(auth()->user()->lessi_role==3){
                $students = Student::where('reference',auth()->user()->id)->where('name','LIKE','%'.$request->input('query').'%')->get();
            }else{
                $students = Student::whereIN('reference',User::select('id')->where('lessi_role','!=',3)->get())->orWhere('reference',null)->where('name','LIKE','%'.$request->input('query').'%')->get();
            }
        }
        $data = [];
        $c = 0;
        foreach ($students as $student){
            array_push($data,[
                'image_url' => str_replace('public/','',$student->image_url),
                'user_id' => $student->user_id,
                'name' => $student->name,
                'contact_no' => $student->users->contact_no,
                'email' => $student->users->email,
                'check' => $student->check,
                'appMicro' => []
            ]);
            foreach($student->studentApplication->applicationMicros as $appMicro){
                $status = ['Under Review','Application Submitted','Approved','Disapproved','LOA'];
                $status_color = ['badge-dark','badge-primary','badge-success','badge-danger','badge-warning'];
                array_push($data[$c]['appMicro'],[
                    'micro_id' => $appMicro->id,
                    'app_id' => $appMicro->application_id,
                    'status' => $status[$appMicro->status -1],
                    'status_color' => $status_color[$appMicro->status -1],
                    'program_name' => $appMicro->program->name,
                    'program_institute' => $appMicro->program->institute->name
                ]);
            }
            $c++;
        }
        return response()->json($data);
    }

}
