<?php

namespace App\Http\Controllers;

use App\Application;
use App\ApplicationMicro;
use App\Mail\Regesteration;
use App\Program;
use App\ProgramCategory;
use App\Student;
use App\StudentEnglishProficiency;
use App\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Str;

class ListingsController extends Controller
{
    public function index()
    {
        $formData = Session::get('find_programs');
        if ( $formData )
        {
            $subjects = ProgramCategory::get();
            $programs = Program::
            select('programs.*')
                ->leftjoin('institutes', 'programs.institute_id', '=', 'institutes.id')
                ->leftjoin('countries', 'institutes.country_id', '=', 'countries.id')
                ->where('program_category_id', $formData['subject'])
                ->whereIn('countries.id', $formData['destination_country'])
                ->paginate(10);
            return view('listings',compact('programs','subjects'));
        }else{
            return '<script>alert("Enable to find record.Search Again"); window.open("'.route('search_program').'","_self")</script>';
        }
    }

    public function SearchPrograms(Request $request){
        $programs = Program::
        select('programs.*')
            ->leftjoin('institutes', 'programs.institute_id', '=', 'institutes.id')
            ->leftjoin('countries', 'institutes.country_id', '=', 'countries.id')
            ->where('program_category_id', $request->program)
            ->whereIn('countries.id', $request->contry)
            ->paginate(10);
        return $programs;
    }

    public function wishListProgram()
    {
        $programs = Program::whereIN('id',Session::get('wish_list'))->get();
        return view('wish_list',compact('programs'));
    }

    public function submitPrograms(Request $request)
    {
        $student = Session::get('find_programs');
//        created user
        if(Auth::check()){
            $role = Auth::user()->id;
        }else{
            $role = User::where('contact_no',$student['contact_no'])->value('id');
        }
        $password = Str::random(8);
        $createdUser = User::create([
            'name' => $student['full_name'],
            'email' => $student['email'],
            'password' => Hash::make($password),
            'contact_no' => $student['contact_no'],
            'lessi_role' => 5
        ]);

//        save student info
        $createdStudent = Student::create([
            'user_id' => $createdUser->id,
            'name' => $student['full_name'],
            'nationality' => $student['nationality'],
            'reference' => $role,
        ]);

//        save student english test info
        StudentEnglishProficiency::create([
            'reading' => $student['reading'],
            'listening' => $student['listening'],
            'speaking' => $student['speaking'],
            'writing' => $student['writing'],
            'english_test_id' => $student['eng_test'],
            'student_id' => $createdStudent->id
        ]);

        $createdApplication = Application::create([
            'student_id' => $createdStudent->id
        ]);

        for ( $i = 0; $i < count($request->program_list); $i++ ) {
            ApplicationMicro::create([
                'application_id' => $createdApplication->id,
                'program_id' => $request->program_list[$i]
            ]);
        }

        Mail::to($student['email'])->send(new Regesteration($student['full_name'],$password));

        Session::forget('find_programs');
        Session::forget('wish_list');
        if(Auth::check()){
            switch (Auth::user()->lessi_role){
                case 1:
                    return redirect()->route('super_admin.dashboard');
                    break;
                case 2:
                    return redirect()->route('admin.dashboard');
                    break;
                case 3:
                    return redirect()->route('agent.dashboard');
                    break;
                case 4:
                    return redirect()->route('employ.dashboard');
                    break;
                case 5:
                    return redirect()->route('student.dashboard');
                    break;
            }
        }else{
            Session::flash('msg', 'success');
            return redirect()->route('login');
        }
    }

    public function updateWishlist(Request $request)
    {
        if($request->has('id') && $request->has('status')){
            if($request->status == 'true'){
                if(Session::has('wish_list')){
                    $data = Session::get('wish_list');
                    array_push($data,$request->id);
                    Session::put(['wish_list'=>$data]);
                }else{
                    Session::put(['wish_list'=>[$request->id]]);
                }
            }else{
                $data = Session::get('wish_list');
                $newData = [];
                for ($i = 0; $i < count($data); $i++){
                    if($data[$i]!=$request->id){
                        array_push($newData,$data[$i]);
                    }
                }
                Session::put('wish_list',$newData);
            }
            return Session::get('wish_list');
        }else{
            return 'fail';
        }
    }
}
