<?php

namespace App\Http\Controllers\Student;

use App\Application;
use App\ApplicationMicro;
use App\ApplicationsMicrosCampus;
use App\EnglishTest;
use App\Http\Controllers\Controller;
use App\Student;
use App\StudentAdditionalEducation;
use App\StudentEducation;
use App\StudentEmployment;
use App\StudentEnglishProficiency;
use App\User;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Validator;
use Illuminate\Validation\Rule;

class DashboardController extends Controller
{
    public function index()
    {
        $student = Student::where('user_id',auth()->user()->id)->first();
        $english_test = EnglishTest::get();
        return view('student.user_info',compact('student','english_test'));
    }

    public function updateStudent(Request $request)
    {
        $request->validate([
            'name' => 'required|max:50',
            'dob' => 'required|date',
            'gender' => Rule::in(['0','1','2']),
            'passport_no' => 'required',
            'nationality' => 'required',
            'po_box' => 'required',
            'address' => 'required',
            'eng_test' => 'required',
            'writing' => 'required',
            'reading' => 'required',
            'speaking' => 'required',
            'listening' => 'required',
            'image' => 'image'
        ]);

        if($request->has('image')){
            $studentPhotoPath = auth()->user()->id.'_'.Carbon::now().'.'.$request->file('image')->extension();
            Student::where('user_id',auth()->user()->id)->update([
                'name' => $request->name,
                'dob' => $request->dob,
                'gender' => $request->gender,
                'passport_no' => $request->passport_no,
                'nationality' => $request->nationality,
                'po_box' => $request->po_box,
                'address' => $request->address,
                'image_url' => $request->file('image')->storeAs('public/Students',str_replace([':',' '],['_','_'],$studentPhotoPath))
            ]);
        }else{
            Student::where('user_id',auth()->user()->id)->update([
                'name' => $request->name,
                'dob' => $request->dob,
                'gender' => $request->gender,
                'passport_no' => $request->passport_no,
                'nationality' => $request->nationality,
                'po_box' => $request->po_box,
                'address' => $request->address
            ]);
        }

        StudentEnglishProficiency::where('student_id',Student::where('user_id',auth()->user()->id)->first()->id)->update([
            'english_test_id' => $request->eng_test,
            'writing' => $request->writing,
            'reading' => $request->reading,
            'speaking' => $request->speaking,
            'listening' => $request->listening
        ]);

        Session::flash('message', 'Student update successfully.');
        return redirect()->route('student.dashboard');
    }

    public function updateEducationHistory(Request $request)
    {
        if($request->id != 0){
            $fileds = [
                'school_name' => 'required',
                'school_address' => 'required',
                'degree_name' => 'required',
                'year' => 'required|digits:4|integer|gt:1900|max:'.(date('Y')+1),
                'result_criteria' => 'required',
                'score' => 'required'
            ];
        }else{
            $fileds = [
                'school_name' => 'required',
                'school_address' => 'required',
                'degree_name' => 'required',
                'year' => 'required|digits:4|integer|gt:1900|max:'.(date('Y')+1),
                'result_criteria' => 'required',
                'score' => 'required',
                'degree' => 'required',
                'result' => 'required'
            ];
        }
        $validator = Validator::make($request->all(),$fileds);

        if($validator->fails()){
            return response()->json(['error'=>$validator->errors()->jsonSerialize()]);
        }

        if($request->has('degree')){
            $degreeFileName = auth()->user()->id.'_'.Carbon::now().'.'.$request->file('degree')->extension();
            $degreepath = $request->file('degree')->storeAs('public\Education\Degrees',str_replace([':',' '],['_','_'],$degreeFileName));
        }else{
            $degreepath = $request->degree_path;
        }
        if($request->has('result')){
            $resultFileName = auth()->user()->id.'_'.Carbon::now().'.'.$request->file('result')->extension();
            $resultPath = $request->file('result')->storeAs('public\Education\Transcripts',str_replace([':',' '],['_','_'],$resultFileName));
        }else{
            $resultPath = $request->result_path;
        }

        StudentEducation::updateOrCreate(['id'=>$request->id],[
            'school_name' => $request->school_name,
            'school_address' => $request->school_address,
            'degree_name' => $request->degree_name,
            'year' => $request->year,
            'result_criteria' => $request->result_criteria,
            'score' => $request->score,
            'degree' => $resultPath,
            'transcript' => $resultPath,
            'student_id' => Student::where('user_id',auth()->user()->id)->first()->id
        ]);

        if($request->id != 0){
            return response()->json(['success'=>'success']);
        }else{
            return response()->json(['success'=>route('student.dashboard')]);
        }

    }

    public function updateAdditionalEducation(Request $request)
    {

        if($request->id != 0){
            $fileds = [
                'school_name' => 'required',
                'certificate_name' => 'required',
                'year' => 'required|digits:4|integer|gt:1900|max:'.(date('Y')+1),
                'tenure' => 'required',
                'description' => 'required'
            ];
        }else{
            $fileds = [
                'school_name' => 'required',
                'certificate_name' => 'required',
                'year' => 'required|digits:4|integer|gt:1900|max:'.(date('Y')+1),
                'tenure' => 'required',
                'description' => 'required',
                'certificate' => 'required'
            ];
        }

        $validator = Validator::make($request->all(),$fileds);

        if($validator->fails()){
            return response()->json(['error'=>$validator->errors()->jsonSerialize()]);
        }

        if($request->certificate){
            $certificateFileName = auth()->user()->id.'_'.Carbon::now().'.'.$request->file('certificate')->extension();
            $certificatePath = $request->file('certificate')->storeAs('public\AdditionalEducation\Certificates',str_replace([':',' '],['_','_'],$certificateFileName));
        }else{
            $certificatePath = $request->certificate_path;
        }

        StudentAdditionalEducation::updateOrCreate(['id'=>$request->id],[
            'school_name' => $request->school_name,
            'name' => $request->certificate_name,
            'year' => $request->year,
            'tenure' => $request->tenure,
            'desc' => $request->description,
            'degree' => $certificatePath,
            'student_id' => Student::where('user_id',auth()->user()->id)->first()->id
        ]);

        if($request->id != 0){
            return response()->json(['success'=>'success']);
        }else{
            return response()->json(['success'=>route('student.dashboard')]);
        }

    }

    public function updateEmploymentHistory(Request $request)
    {
        if($request->id != 0){
            $fileds = [
                'company_name' => 'required',
                'company_address' => 'required',
                'designation' => 'required',
                'from' => 'required',
            ];
        }else{
            $fileds = [
                'company_name' => 'required',
                'company_address' => 'required',
                'designation' => 'required',
                'from' => 'required',
                'experience_letter' => 'required',
                'last_pay_slip' => 'required'
            ];
        }

        if($request->has('check') == false){
            $fileds += [
                'to' => 'required'
            ];
        }

        $validator = Validator::make($request->all(),$fileds);

        if($validator->fails()){
            return response()->json(['error'=>$validator->errors()->jsonSerialize()]);
        }

        if($request->has('experience_letter')){
            $experienceFileName = auth()->user()->id.'_'.Carbon::now().'.'.$request->file('experience_letter')->extension();
            $experiencePath = $request->file('experience_letter')->storeAs('public\Employment\PaySlip',str_replace([':',' '],['_','_'],$experienceFileName));
        }else{
            $experiencePath = $request->experience_path;
        }
        if($request->has('last_pay_slip')){
            $paySlipFileName = auth()->user()->id.'_'.Carbon::now().'.'.$request->file('last_pay_slip')->extension();
            $slipPath = $request->file('last_pay_slip')->storeAs('public\Employment\PaySlip',str_replace([':',' '],['_','_'],$paySlipFileName));
        }else{
            $slipPath = $request->slip_path;
        }

        StudentEmployment::updateOrCreate(['id'=>$request->id],[
            'company_name' => $request->company_name,
            'company_address' => $request->company_address,
            'position' => $request->designation,
            'from' => $request->from,
            'to' => $request->to,
            'experience_letter' => $experiencePath,
            'last_pay_slip' => $slipPath,
            'student_id' => Student::where('user_id',auth()->user()->id)->first()->id
        ]);

        if($request->id != 0){
            return response()->json(['success'=>'success']);
        }else{
            return response()->json(['success'=>route('student.dashboard')]);
        }
    }

    public function updateProgram(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'campus' => 'required',
            'intake' => 'required',
            'time' => 'required'
        ]);

        if ( $validator->fails() ) {
            return response()->json(['error'=>$validator->errors()]);
        }

        $appId = Application::where('student_id',Student::where('student_id',auth()->user()->id)->first()->id)->first()->id;

        ApplicationMicro::where('application_id',$appId)
            ->where('program_id',$request->program_id)
            ->update([
                'intake_program_id' => $request->intake,
                'program_time_type_id' => $request->time
            ]);

        $appMicroId = ApplicationMicro::where('application_id',$appId)
            ->where('program_id',$request->program_id)->get();

        foreach ($appMicroId as $id){
            for ($i = 0; $i < count($request->campus); $i++){
                ApplicationsMicrosCampus::create([
                    'application_micro_id' => $id->id,
                    'campus_id' => $request->campus[$i]
                ]);
            }
        }
    }

    public function lock(){
        if(Student::where('user_id',auth()->user()->id)->update(['check'=>true])==false){
            Session::flash("lock_error", "Something went's wrong try gain later.");
        }
        return redirect()->back();
    }

}
