<?php

namespace App\Http\Controllers\SuperAdmin;

use App\ApplicationMicro;
use App\Mail\Regesteration;
use App\Student;
use App\User;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Str;

class AdminManagerController extends Controller
{

    public function searchAdmins(Request $request)
    {
        return User::where('lessi_role',2)->where('name','LIKE','%'.$request->name.'%')->get();
    }

    public function searchAgents(Request $request)
    {
        $agents = User::where('lessi_role',3)->where('name','LIKE','%'.$request->name.'%')->get();
        $data = [];
        foreach ($agents as $agent){
            array_push($data,[
                'id' => $agent->id,
                'name' => $agent->name,
                'avatar' => $agent->avatar,
                'contact_no' => $agent->contact_no,
                'email' => $agent->email,
                'number' => Student::where('reference',$agent->id)->count()
            ]);
        }
        return $data;
    }

    public function searchEmploys(Request $request)
    {
        return User::where('lessi_role',4)->where('name','LIKE','%'.$request->name.'%')->get();
    }

//  -------------------------------------

    public function createAdmin(Request $request)
    {
        return $this->createNewAdmin($request->all(),2,'super_admin.register_admin');
    }

    public function createAgent(Request $request)
    {
        return $this->createNewAdmin($request->all(),3,'super_admin.register_agent');
    }

    public function createEmploy(Request $request)
    {
        return $this->createNewAdmin($request->all(),4,'super_admin.register_employ');
    }

    public function validateForm($formData)
    {
        return Validator::make($formData, [
            'name' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:users'],
            'contact_no' => ['required','max:15','unique:users'],
        ]);
    }

    public function createNewAdmin($data,$lessi_role,$path)
    {
        $this->validateForm($data)->validate();
        $password = Str::random(8);
        User::create([
            'name' => $data['name'],
            'email' => $data['email'],
            'password' => Hash::make($password),
            'contact_no' => $data['contact_no'],
            'lessi_role' => $lessi_role,
        ]);

        Mail::to($data['email'])->send(new Regesteration($data['name'],$password));

        Session::flash('msg', 'Admin created successfully.');
        return redirect()->route($path);
    }

//    ----------------------------------------------
    public function updateStatus(Request $request)
    {
        if($request->has('id') && $request->has('status')){
            ApplicationMicro::where('id',$request->id)->update([
                'status' => $request->status
            ]);
            return true;
        }else{
            return false;
        }
    }
}
